@@ -439,7 +439,7 @@ class TransmageddonUI(Gtk.ApplicationWindow):
                             _("Horizontal flip"),
                             _("Vertical flip"), \
                             _("Upper left diagonal flip"),
-                            _("Upper right diagnonal flip") ]
+                            _("Upper right diagonal flip") ]
 
        for y in self.rotationlist: 
            self.rotationchoice.append_text(y)
@@ -1476,6 +1476,8 @@ import signal
 gettext.bindtextdomain("transmageddon","../../share/locale")
 gettext.textdomain("transmageddon")
 
+GLib.set_prgname("transmageddon")
+
 if __name__ == "__main__":
     app = Transmageddon()
     # FIXME: Get rid of the following line which has the only purpose of
